Skip to content

CLI Reference

The create-express-forge command can be used with various flags to bypass the interactive prompts and speed up your workflow.

Usage

bash
npx create-express-forge [project-name] [options]

Options

FlagDescriptionValues
--helpShow help information-
--versionShow current version-
--patternArchitecture patternmodular, mvc
--ormORM to useprisma, sequelize, none
--dbDatabase typepostgres, mysql, sqlite
--loggerLogging librarywinston, pino
--testTesting frameworkvitest, jest
--dockerInclude Docker setuptrue, false
--installAuto-install dependenciestrue, false

Example

Scaffold a modular project with Prisma and Vitest:

bash
npx create-express-forge my-api --pattern modular --orm prisma --test vitest --install true

Released under the MIT License.